==> paragraphs_filter-1.0.0.tar.gz: paragraphs_filter/src/Form/ParagraphsFilterForm.php <==
<?php

namespace Drupal\paragraphs_filter\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a filter for paragraph types list page.
 */
class ParagraphsFilterForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'paragraphs_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $entityTypeManager = \Drupal::service('entity_type.manager');
    $options = ['All' => $this->t('- Any -')];
    $contentTypes = $entityTypeManager->getStorage('node_type')->loadMultiple();
    foreach ($contentTypes as $contentType) {
      $options[$contentType->id()] = $contentType->label();
    }

    $form['content_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Content type'),
      '#options' => $options,
      '#default_value' => \Drupal::request()->get('content_type'),
      '#wrapper_attributes' => [
        'class' => [
          'views-exposed-form__item',
          'views-exposed-form__item--preceding-actions',
        ],
      ],
    ];
    $form['actions'] = [
      '#type' => 'actions',
      '#attributes' => [
        'class' => [
          'views-exposed-form__item',
          'views-exposed-form__item--actions',
        ],
      ],
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];
    $form['#attributes']['class'][] = 'views-exposed-form';
    $form['#attached']['library'][] = 'claro/views';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $options = [];
    $content_type = $form_state->getValue('content_type');
    if ($content_type != 'All') {
      $options = [
        'query' => ['content_type' => $content_type],
      ];
    }
    $form_state->setRedirect('entity.paragraphs_type.collection', [], $options);
  }

}

==> paragraphs_filter-1.0.1.tar.gz: paragraphs_filter/src/Form/ParagraphsFilterForm.php <==
<?php

namespace Drupal\paragraphs_filter\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a filter for paragraph types list page.
 */
class ParagraphsFilterForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'paragraphs_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $entityTypeManager = \Drupal::service('entity_type.manager');
    $options = ['All' => $this->t('- Any -')];
    $contentTypes = $entityTypeManager->getStorage('node_type')->loadMultiple();
    foreach ($contentTypes as $contentType) {
      $options[$contentType->id()] = $contentType->label();
    }

    $form['content_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Content type'),
      '#options' => $options,
      '#default_value' => $this->getRequest()->get('content_type'),
      '#wrapper_attributes' => [
        'class' => [
          'views-exposed-form__item',
          'views-exposed-form__item--preceding-actions',
        ],
      ],
    ];
    $form['actions'] = [
      '#type' => 'actions',
      '#attributes' => [
        'class' => [
          'views-exposed-form__item',
          'views-exposed-form__item--actions',
        ],
      ],
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];
    $content_type = $this->getRequest()->get('content_type');
    if (!empty($content_type)) {
      $form['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
      ];
    }
    $form['#attributes']['class'][] = 'views-exposed-form';
    $form['#attached']['library'][] = 'claro/views';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->isValueEmpty('op') &&
      $form_state->getValue('op')->getUntranslatedString() == $this->t('Reset')
        ->getUntranslatedString()) {
      $form_state->setRedirect('entity.paragraphs_type.collection');
      return;
    }
    $options = [];
    $content_type = $form_state->getValue('content_type');
    if ($content_type != 'All') {
      $options = [
        'query' => ['content_type' => $content_type],
      ];
    }
    $form_state->setRedirect('entity.paragraphs_type.collection', [], $options);
  }

}
